@@ -5,6 +5,7 @@
 #'
 #' @param warp_data fdawarp object from \link{time_warping} of aligned data
 #' @param no number of principal components to extract
+#' @param ci geodesic standard deviations (default = c(-1,0,1))
 #' @param showplot show plots of principal directions (default = T)
 #' @return Returns a hfpca object containing \item{gam_pca}{warping functions principal directions}
 #' \item{psi_pca}{srvf principal directions}
@@ -20,13 +21,12 @@
 #' @examples
 #' data("simu_warp")
 #' hfpca = horizFPCA(simu_warp,no = 3)
-horizFPCA <- function(warp_data,no,showplot = TRUE){
+horizFPCA <- function(warp_data,no,ci=c(-1,0,1),showplot = TRUE){
     gam <- warp_data$gam
     tmp = SqrtMean(gam)
     vec = tmp$vec
     mu = tmp$mu
     # Parameters
-    tau = 1:5 # -2, -1, 0, 1, 2 std from the mean
     no_pca = 1:no
 
     # TFPCA
@@ -38,21 +38,21 @@ horizFPCA <- function(warp_data,no,showplot = TRUE){
     TT = nrow(vec) + 1
     vm = rowMeans(vec)
 
-    gam_pca = array(0,dim=c(length(tau),length(mu)+1,no))
-    psi_pca = array(0,dim=c(length(tau),length(mu),no))
+    gam_pca = array(0,dim=c(length(ci),length(mu)+1,no))
+    psi_pca = array(0,dim=c(length(ci),length(mu),no))
     for (j in no_pca){
         cnt = 1
-        for (k in tau){
-            v = (k-3)*sqrt(s[j])*U[,j]
+        for (k in ci){
+            v = ci*sqrt(s[j])*U[,j]
             vn = pvecnorm(v,2)/sqrt(TT)
             if (vn < 0.0001){
-                psi_pca[k,,j] = mu
+                psi_pca[cnt,,j] = mu
             }else{
-                psi_pca[k,,j] = cos(vn)*mu+sin(vn)*v/vn
+                psi_pca[cnt,,j] = cos(vn)*mu+sin(vn)*v/vn
             }
             tmp = rep(0,TT)
-            tmp[2:TT] = cumsum(psi_pca[k,,j]*psi_pca[k,,j])
-            gam_pca[k,,j] = (tmp-tmp[1]) / (tmp[length(tmp)] - tmp[1])
+            tmp[2:TT] = cumsum(psi_pca[cnt,,j]*psi_pca[cnt,,j])
+            gam_pca[cnt,,j] = (tmp-tmp[1]) / (tmp[length(tmp)] - tmp[1])
             cnt = cnt + 1
         }
     }
