@@ -6,7 +6,8 @@
 #' @param sigma variance of warping functions
 #' @param num number of warping functions
 #' @return gam warping functions
-#' @keywords diffeomorphism, warping function
+#' @keywords warping function
+#' @concept diffeomorphism
 #' @references Srivastava, A., Wu, W., Kurtek, S., Klassen, E., Marron, J. S.,
 #'  May 2011. Registration of functional data using fisher-rao metric,
 #'  arXiv:1103.3817v2 [math.ST].
@@ -23,12 +24,12 @@ rgam <- function(N, sigma, num){
     TT = N - 1
     time = seq(0,1,length.out=TT)
     mu = sqrt(rep(1,N-1)*TT/(N-1))
-    omega = (2*pi)/TT
+    omega = 2*pi
     for (k in 1:num){
         alpha_i = rnorm(1,sd=sigma)
         v = alpha_i * rep(1,TT)
         cnt = 1
-        for (l in 2:10){
+        for (l in 2:3){
             alpha_i = rnorm(1,sd=sigma)
             if (l %% 2 !=0){#odd
                 v = v + alpha_i*sqrt(2)*cos(cnt*omega*time)
@@ -45,5 +46,13 @@ rgam <- function(N, sigma, num){
 
     }
 
+    gamI = SqrtMeanInverse(t(gam))
+    time = seq(0,1,length.out=N)
+    for (k in 1:num){
+        gam0 = approx(time,gam[k,],xout=(time[length(time)]-time[1])*gamI +
+            time[1])$y
+        gam[k,] = (gam0-gam0[1])/(gam0[length(gam0)]-gam0[1])
+    }
+
     return(gam)
 }
